@@ -9,8 +9,8 @@ from uno import createUnoStruct
 from unogenerator.reusing.listdict_functions import listdict_min
 from time import sleep
 
-__version__ = '0.20.0'
-__versiondatetime__=datetime(2022, 3, 6, 18, 39)
+__version__ = '0.21.0'
+__versiondatetime__=datetime(2022, 3, 9, 12, 8)
 __versiondate__=__versiondatetime__.date()
 
 try:
@@ -217,6 +217,12 @@ class Range:
         
     def __str__(self):
         return self.string()
+        
+    @classmethod
+    def from_coords_indexes(cls, start_letter_index, start_number_index, end_letter_index, end_number_index):
+        c_start=Coord_from_index(start_letter_index, start_number_index)
+        c_end=Coord_from_index(end_letter_index, end_number_index)
+        return cls(f"{c_start}:{c_end}")
 
     ##Return the outcome of the test b in a. Note the reversed operands.
     def __contains__(self, b):
